@@ -1,5 +1,13 @@
+"""
+car_input_parameters.py contains the CarInputParameters class, which, after instantiated, contains
+all definitions (metadata) of input and calculated parameters, along with their values.
+Also, it inherits methods from `klausen`, which exposes the methods .static() and .stochastic(),
+which generate single or random values for input parameters.
+"""
+
 import json
 from pathlib import Path
+from typing import Union
 
 from klausen import NamedParameters
 
@@ -7,13 +15,18 @@ DEFAULT = Path(__file__, "..").resolve() / "data" / "default_parameters.json"
 EXTRA = Path(__file__, "..").resolve() / "data" / "extra_parameters.json"
 
 
-def load_parameters(obj):
+def load_parameters(obj: Union[str, Path, list]) -> list:
+    """
+    Returns a json object containing parameters' definitions
+    :param obj: A filepath to a json file, or a json object
+    :return: Returns a json object containing parameters' definitions
+    """
     if isinstance(obj, (str, Path)):
         assert Path(obj).exists(), "Can't find this filepath"
-        return json.load(open(obj))
-    else:
-        # Already in correct form, just return
-        return obj
+        return json.load(open(obj, encoding="utf-8"))
+
+    # Already in correct form, just return
+    return obj
 
 
 class CarInputParameters(NamedParameters):
@@ -26,17 +39,12 @@ class CarInputParameters(NamedParameters):
     in the *klausen* package.
 
     :ivar sizes: List of string items e.g., ['Large', 'Lower medium', 'Medium', 'Mini', 'Medium SUV', 'Small', 'Van']
-    :vartype sizes: list
     :ivar powertrains: List of string items e.g., ['BEV', 'FCEV', 'HEV-p', 'ICEV-d', 'ICEV-g', 'ICEV-p', 'PHEV-c', 'PHEV-e']
-    :vartype powertrains: list
-    :ivar parameters: List of string items e.g., ['Benzene', 'CH4', 'CNG tank mass intercept',...]
-    :vartype parameters: list
+    :ivar parameters: json or filepath to json containing input parameter's definitions
+    :ivar extra: json or filepath to json containing calculated parameter's definitions
     :ivar years: List of integers e.g., [2000, 2010, 2020, 2040]
-    :vartype years: list
     :ivar metadata: Dictionary for metadata.
-    :vartype metadata: dict
     :ivar values: Dictionary for storing values, of format {'param':[value]}.
-    :vartype values: dict
     :ivar iterations: Number of iterations executed by the method :func:`~car_input_parameters.CarInputParameters.stochastic`.
         None if :func:`~car_input_parameters.CarInputParameters.static` used instead.
     :vartype iterations: int
@@ -44,7 +52,11 @@ class CarInputParameters(NamedParameters):
 
     """
 
-    def __init__(self, parameters=None, extra=None, limit=None):
+    def __init__(
+        self,
+        parameters: Union[str, Path, list] = None,
+        extra: Union[str, Path, list] = None,
+    ) -> None:
         """Create a `klausen <https://github.com/cmutel/klausen>`__ model with the car input parameters."""
         super().__init__(None)
 
@@ -53,15 +65,11 @@ class CarInputParameters(NamedParameters):
 
         if not isinstance(parameters, dict):
             raise ValueError(
-                "Parameters are not correct type (expected `dict`, got `{}`)".format(
-                    type(parameters)
-                )
+                f"Parameters are not correct type (expected `dict`, got `{type(parameters)}`)"
             )
         if not isinstance(extra, set):
             raise ValueError(
-                "Extra parameters are not correct type (expected `set`, got `{}`)".format(
-                    type(extra)
-                )
+                f"Extra parameters are not correct type (expected `set`, got `{type(extra)}`)"
             )
         self.sizes = sorted(
             {size for o in parameters.values() for size in o.get("sizes", [])}
@@ -79,7 +87,7 @@ class CarInputParameters(NamedParameters):
         self.years = sorted({o["year"] for o in parameters.values()})
         self.add_car_parameters(parameters)
 
-    def add_car_parameters(self, parameters):
+    def add_car_parameters(self, parameters: dict) -> None:
         """
         Split data and metadata according to ``klausen`` convention.
 
@@ -91,13 +99,13 @@ class CarInputParameters(NamedParameters):
 
 
         """
-        KEYS = {"kind", "uncertainty_type", "amount", "loc", "minimum", "maximum"}
+        keys = {"kind", "uncertainty_type", "amount", "loc", "minimum", "maximum"}
 
         reformatted = {}
         for key, dct in parameters.items():
-            reformatted[key] = {k: v for k, v in dct.items() if k in KEYS}
+            reformatted[key] = {k: v for k, v in dct.items() if k in keys}
             reformatted[key]["metadata"] = {
-                k: v for k, v in dct.items() if k not in KEYS
+                k: v for k, v in dct.items() if k not in keys
             }
 
         self.add_parameters(reformatted)
